# 🔐 GitHub Secrets Setup for PyDoll MCP Server

This guide explains how to configure GitHub Actions secrets for automated releases and deployments.

## 📋 Required GitHub Secrets

Configure the following secrets in your GitHub repository settings:

### Repository Secrets (Settings > Secrets and variables > Actions)

| Secret Name | Description | Value |
|-------------|-------------|-------|
| `TWINE_USERNAME` | PyPI username | `METAVU` |
| `TWINE_PASSWORD` | PyPI API token | `pypi-AgEIcHlwaS5vcmcC...` (your full token) |
| `SMITHERY_AI_KEY` | Smithery.ai API key | `d5b3fc68-2ac2-4403-842f-3fe77df88b75` |

## 🔧 Step-by-Step Setup

### 1. Navigate to Repository Settings
1. Go to your repository: https://github.com/JinsongRoh/pydoll-mcp
2. Click on **Settings** tab
3. In the left sidebar, find **Secrets and variables** > **Actions**

### 2. Add Repository Secrets

Click **New repository secret** for each:

#### TWINE_USERNAME
```
Name: TWINE_USERNAME
Secret: METAVU
```

#### TWINE_PASSWORD
```
Name: TWINE_PASSWORD
Secret: pypi-AgEIcHlwaS5vcmcCJGIxZjM2NDgzLTA3ZTUtNGQ5My1iYmMwLWQ3YTAwZWRmMjE2NwACElsxLFsicHlkb2xsLW1jcCJdXQACLFsyLFsiMTA2NmVhZDAtODg2NC00YmRiLTliNjEtMDg5NGY5NTExMWY0Il1dAAAGICbBeGmmzZ9weXCL-90W-djS0kyl1v2ACWCR6ufW49hq
```

#### SMITHERY_AI_KEY
```
Name: SMITHERY_AI_KEY
Secret: d5b3fc68-2ac2-4403-842f-3fe77df88b75
```

## 🚀 Automated Deployment Process

When you create a new release tag (e.g., `v1.5.15`), the workflow will automatically:

1. **Create GitHub Release** with assets
2. **Upload to PyPI** using the configured credentials
3. **Update Smithery.ai** registry
4. **Verify deployment** and generate reports

### Triggering a Release

#### Option 1: Create a Git Tag
```bash
git tag v1.5.15
git push origin v1.5.15
```

#### Option 2: Manual Workflow Dispatch
1. Go to **Actions** tab
2. Select **🚀 Release and Deploy PyDoll MCP Server**
3. Click **Run workflow**
4. Enter version number (e.g., `1.5.15`)
5. Click **Run workflow**

## 🔍 Verification

After setting up secrets, you can verify they're configured:

1. Go to **Settings** > **Secrets and variables** > **Actions**
2. You should see:
   - TWINE_USERNAME
   - TWINE_PASSWORD
   - SMITHERY_AI_KEY

## 📊 Monitoring Deployments

Track deployment status:
- **GitHub Actions**: https://github.com/JinsongRoh/pydoll-mcp/actions
- **PyPI Package**: https://pypi.org/project/pydoll-mcp/
- **Smithery.ai**: https://smithery.ai/server/@JinsongRoh/pydoll-mcp

## 🆘 Troubleshooting

### PyPI Upload Fails
- Verify `TWINE_USERNAME` and `TWINE_PASSWORD` are correct
- Check if the token has upload permissions
- Ensure the version doesn't already exist on PyPI

### Smithery.ai Update Fails
- Verify `SMITHERY_AI_KEY` is correct
- Check Smithery.ai service status
- The workflow continues even if Smithery update fails

### GitHub Release Fails
- Ensure the tag doesn't already exist
- Check repository permissions
- Verify GitHub Actions is enabled

## 🔒 Security Notes

- Never commit secrets to the repository
- Rotate tokens regularly (every 6 months)
- Use project-scoped PyPI tokens when possible
- Monitor for unauthorized access in PyPI and GitHub logs

---

**Last Updated**: 2025-07-20
**Workflow File**: `.github/workflows/release.yml`